# PostPaymentScheduleRequestAllOfBillingDocumentType

The type of the billing document. The default value is `Invoice`. 

## Enum

* `INVOICE` (value: `'Invoice'`)

* `DEBITMEMO` (value: `'DebitMemo'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


